@@ -224,14 +224,19 @@ def stackedplot(rets, xlabel='injection #'):
 
 
 if CHEMSTATION_DATA_PATH is not None:
-    datawatch = Watcher(  # create watcher for HPLC output files
-        CHEMSTATION_DATA_PATH,
-        'Report.TXT'
-    )
-    acqwatch = Watcher(  # watcher for acquiring text file
-        CHEMSTATION_DATA_PATH,
-        'ACQUIRING.TXT'
-    )
+    try:
+        datawatch = Watcher(  # create watcher for HPLC output files
+            CHEMSTATION_DATA_PATH,
+            'Report.TXT'
+        )
+        acqwatch = Watcher(  # watcher for acquiring text file
+            CHEMSTATION_DATA_PATH,
+            'ACQUIRING.TXT'
+        )
+    # catch for non-windows systems trying to create documentation
+    except ValueError:
+        datawatch = None
+        acqwatch = None
 else:
     datawatch = None
     acqwatch = None
